# eric7.Plugins.VcsPlugins.vcsGit.GitPatchFilesDialog

Module implementing a dialog to select a list of patch files.

### Global Attributes

None

### Classes

GitPatchFilesDialog | Class implementing a dialog to select a list of patch files.

### Functions

None

## GitPatchFilesDialog

Class implementing a dialog to select a list of patch files.

### Derived from

QDialog, Ui_GitPatchFilesDialog

### Class Attributes

None

### Class Methods

None

### Methods

GitPatchFilesDialog | Constructor
__getPatchFilesList | Private method to get the list of patch files.
getData | Public slot to get the entered data.
on_addButton_clicked | Private slot to add patch files to the list.
on_deleteButton_clicked | Private slot to delete the selected patch files.
on_downButton_clicked | Private slot to move an entry down in the list.
on_patchFilesList_itemSelectionChanged | Private slot to enable button states depending on selection.
on_upButton_clicked | Private slot to move an entry up in the list.

### Static Methods

None

#### GitPatchFilesDialog (Constructor)

GitPatchFilesDialog(rootDir, patchCheckData, parent=None)

Constructor

rootDir (str)
  root of the directory tree
patchCheckData (tuple of (list of str, int, bool, bool))
  tuple of data as returned by the getData() method
parent (QWidget)
  reference to the parent widget

#### GitPatchFilesDialog.__getPatchFilesList

__getPatchFilesList()

Private method to get the list of patch files.

Return:
  list of patch files

Return Type:
  list of str

#### GitPatchFilesDialog.getData

getData()

Public slot to get the entered data.

Return:
  tuple of list of patch files, strip count, flag indicating that the patch has inaccurate end-of-file marker and a flag indicating to not trust the line count information

Return Type:
  tuple of (list of str, int, bool, bool)

#### GitPatchFilesDialog.on_addButton_clicked

on_addButton_clicked()

Private slot to add patch files to the list.

#### GitPatchFilesDialog.on_deleteButton_clicked

on_deleteButton_clicked()

Private slot to delete the selected patch files.

#### GitPatchFilesDialog.on_downButton_clicked

on_downButton_clicked()

Private slot to move an entry down in the list.

#### GitPatchFilesDialog.on_patchFilesList_itemSelectionChanged

on_patchFilesList_itemSelectionChanged()

Private slot to enable button states depending on selection.

#### GitPatchFilesDialog.on_upButton_clicked

on_upButton_clicked()

Private slot to move an entry up in the list.

Up